@@ -26,6 +26,14 @@ class App(metaclass=AppMeta):
     def __bareinit__(self):
         pass
 
+    @classmethod
+    def entry_point(cls):
+        app = cls.from_params()
+        app.main()
+
+    def main(self):
+        raise NotImplementedError
+
     def load(self, config_cls=None):
         model.load(self, config_cls)
 
@@ -33,4 +41,3 @@ class App(metaclass=AppMeta):
         model.reload(self, config_cls)
 
 
-
