@@ -8,6 +8,7 @@ from ..errors import ConfigError
 from pathlib import Path
 from textwrap import dedent
 from more_itertools import one, first
+from collections.abc import Iterable
 
 class Config:
     autoload = True
@@ -231,15 +232,28 @@ class FileConfig(Config):
     schema = None
     root_key = None
 
-    def get_path(self):
-        return Path(unbind_method(self.path_getter)(self.obj))
+    def __init__(self, obj, path=None, *, path_getter=None, schema=None, root_key=None):
+        super().__init__(obj)
+        self._path = path
+        self._path_getter = path_getter or unbind_method(self.path_getter)
+        self.schema = schema or self.schema
+        self.root_key = root_key or self.root_key
+
+    def get_paths(self):
+        p = self._path or self._path_getter(self.obj)
+
+        if isinstance(p, Iterable) and not isinstance(p, str):
+            return [Path(pi) for pi in p]
+        else:
+            return [Path(p)]
 
     def load(self):
-        yield from self.load_from_path(
-                path=self.path,
-                schema=self.schema,
-                root_key=self.root_key
-        )
+        for path in self.paths:
+            yield from self.load_from_path(
+                    path=path,
+                    schema=self.schema,
+                    root_key=self.root_key,
+            )
 
     @classmethod
     def load_from_path(cls, path, *, schema=None, root_key=None):
@@ -274,25 +288,9 @@ class TomlConfig(FileConfig):
 
     @staticmethod
     def _do_load(path):
-        # rtoml requires this.
-        path = Path(path)
-
-        try:
-            # Prefer rtoml, since it's much less buggy.  It's also much harder 
-            # to install, though.
-            import rtoml
-            return rtoml.load(path)
-        except ModuleNotFoundError:
-            pass
-
-        try:
-            import tomli
-            return tomli.load(path)
-        except ModuleNotFoundError:
-            pass
-
-        import toml
-        return toml.load(path)
+        import tomli
+        with open(path, 'rb') as f:
+            return tomli.load(f)
 
 
 class NtConfig(FileConfig):
