@@ -15,11 +15,22 @@ class LayerWrapper:
         return f'LayerWrapper({self.layer!r})'
 
     def __eq__(self, other):
-        return all((
-                isinstance(other, appcli.Layer),
-                self.layer.values == other.values,
-                self.layer.location == str(other.location),
-        ))
+        if not isinstance(other, appcli.Layer):
+            return False
+
+        if self.layer.values != other.values:
+            return False
+
+        if self.layer.location != str(other.location):
+            return False
+
+        if hasattr(self.layer, 'root_key') and self.layer.root_key != other.root_key:
+            return False
+
+        if hasattr(self.layer, 'schema') and self.layer.schema != other.schema:
+            return False
+
+        return True
 
 def DictLayerWrapper(*args, **kwargs):
     return LayerWrapper(appcli.DictLayer(*args, **kwargs))
@@ -36,19 +47,25 @@ def eval_appcli(code, globals=None, **kw_globals):
     except Exception as err:
         raise Invalid(str(err)) from err
 
-def eval_layers(layers, globals=None, **kw_globals):
+def eval_obj_layers(layers, globals=None, **kw_globals):
     schema = Schema({
-        Coerce(int): Or(
+        Coerce(int): eval_config_layers,
+    })
+    return schema(layers)
+
+def eval_config_layers(layers, globals=None, **kw_globals):
+    schema = Schema(Or(
             [lambda x: eval_layer(x, globals, **kw_globals)],
             empty_list,
-        ),
-    })
+    ))
     return schema(layers)
 
 def eval_layer(layer, globals=None, **kw_globals):
     schema = Schema(Or(str, {
         'values': eval,
         'location': str,
+        Optional('root_key'): eval,
+        Optional('schema'): eval,
     }))
     layer = schema(layer)
     layer = eval_appcli(layer, globals, **kw_globals) \
